@@ -333,9 +333,7 @@ static int register_persistent_environment(void)
 	/* use the full partition as our persistent environment storage */
 	cdev = devfs_add_partition("disk0.1", 0, cdev->size,
 					DEVFS_PARTITION_FIXED, "env0");
-	if (IS_ERR(cdev))
-		return PTR_ERR(cdev);
-	return 0;
+	return PTR_ERR_OR_ZERO(cdev);
 }
 
 static void tx28_get_ethaddr(void)
