@@ -10,6 +10,7 @@
 #include <mach/generic.h>
 #include <mach/gpmc.h>
 #include <mach/omap4_rom_usb.h>
+#include <mach/omap4-generic.h>
 
 /*
  *  The following several lines are taken from U-Boot to support
@@ -179,7 +180,7 @@ static inline void delay(unsigned long loops)
 			  "bne 1b" : "=r" (loops) : "0"(loops));
 }
 
-int omap4_emif_config(unsigned int base, const struct ddr_regs *ddr_regs)
+static int omap4_emif_config(unsigned int base, const struct ddr_regs *ddr_regs)
 {
 	/*
 	 * set SDRAM CONFIG register
@@ -684,5 +685,8 @@ static int omap4_gpio_init(void)
 
 int omap4_devices_init(void)
 {
-	return omap4_gpio_init();
+	omap4_gpio_init();
+	add_generic_device("omap-32ktimer", 0, NULL, OMAP44XX_32KTIMER_BASE, 0x400,
+			   IORESOURCE_MEM, NULL);
+	return 0;
 }
