@@ -15,11 +15,9 @@
 
 #include <common.h>
 #include <command.h>
-#include <kfifo.h>
 #include <malloc.h>
 #include <init.h>
 #include <ratp.h>
-#include <command.h>
 #include <byteorder.h>
 #include <environment.h>
 #include <kfifo.h>
@@ -27,6 +25,7 @@
 #include <linux/sizes.h>
 #include <ratp_bb.h>
 #include <fs.h>
+#include <console_countdown.h>
 
 LIST_HEAD(ratp_command_list);
 EXPORT_SYMBOL(ratp_command_list);
@@ -473,6 +472,8 @@ int barebox_ratp(struct console_device *cdev)
 
 	ctx->poller_registered = true;
 
+	console_countdown_abort();
+
 	console_set_active(&ctx->ratp_console, CONSOLE_STDOUT | CONSOLE_STDERR |
 			CONSOLE_STDIN);
 
