@@ -57,9 +57,14 @@ int nvmem_device_write(struct nvmem_device *nvmem, unsigned int offset,
 static ssize_t nvmem_cdev_read(struct cdev *cdev, void *buf, size_t count,
 			       loff_t offset, unsigned long flags)
 {
-	struct nvmem_device *nvmem = container_of(cdev, struct nvmem_device, cdev);
+	struct nvmem_device *nvmem;
 	ssize_t retlen;
 
+	if (cdev->master)
+		nvmem = container_of(cdev->master, struct nvmem_device, cdev);
+	else
+		nvmem = container_of(cdev, struct nvmem_device, cdev);
+
 	dev_dbg(cdev->dev, "read ofs: 0x%08llx count: 0x%08zx\n",
 		offset, count);
 
@@ -71,9 +76,14 @@ static ssize_t nvmem_cdev_read(struct cdev *cdev, void *buf, size_t count,
 static ssize_t nvmem_cdev_write(struct cdev *cdev, const void *buf, size_t count,
 				loff_t offset, unsigned long flags)
 {
-	struct nvmem_device *nvmem = container_of(cdev, struct nvmem_device, cdev);
+	struct nvmem_device *nvmem;
 	ssize_t retlen;
 
+	if (cdev->master)
+		nvmem = container_of(cdev->master, struct nvmem_device, cdev);
+	else
+		nvmem = container_of(cdev, struct nvmem_device, cdev);
+
 	dev_dbg(cdev->dev, "write ofs: 0x%08llx count: 0x%08zx\n",
 		offset, count);
 
