@@ -4,9 +4,6 @@
  *
  * (C) Copyright 2011 - Franck JULLIEN <elec4fun@gmail.com>
  *
- * See file CREDITS for list of people who contributed to this
- * project.
- *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of
@@ -82,6 +79,7 @@ static int altera_serial_jtag_getc(struct console_device *cdev)
 }
 
 static int altera_serial_jtag_probe(struct device_d *dev) {
+	struct resource *iores;
 
 	struct console_device *cdev;
 	struct altera_serial_jtag_priv *priv;
@@ -89,7 +87,10 @@ static int altera_serial_jtag_probe(struct device_d *dev) {
 	priv = xzalloc(sizeof(*priv));
 	cdev = &priv->cdev;
 
-	priv->regs = dev_request_mem_region(dev, 0);
+	iores = dev_request_mem_resource(dev, 0);
+	if (IS_ERR(iores))
+		return PTR_ERR(iores);
+	priv->regs = IOMEM(iores->start);
 	cdev->dev = dev;
 	cdev->tstc = altera_serial_jtag_tstc;
 	cdev->putc = altera_serial_jtag_putc;
